#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_device_images_activate_bulk
short_description: Resource module for Network Device Images Activate Bulk
description:
  - Manage operation create of the resource Network Device Images Activate Bulk.
  - This API initiates the process of updating the software image on the given network devices.
  - Providing value for the `installedImages` in request payload will initiate both distribution and activation.
  - At the end of this process, only the images which are part of `installedImages` will be running on the devices.
  - To monitor the progress and completion of the update task, call the GET API
    `/dna/intent/api/v1/networkDeviceImageUpdates?parentId={taskId}`, where `taskId` is from the response.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  payload:
    description: Network Device Images Activate Bulk's payload.
    elements: dict
    suboptions:
      compatibleFeatures:
        description: Network Device Images Activate Bulk's compatibleFeatures.
        elements: dict
        suboptions:
          key:
            description: Name of the compatible feature.
            type: str
          value:
            description: Feature that can be enabled or disabled.
            type: str
        type: list
      id:
        description: Network device identifier.
        type: str
      installedImages:
        description: Network Device Images Activate Bulk's installedImages.
        elements: dict
        suboptions:
          id:
            description: Software image identifier.
            type: str
        type: list
      networkValidationIds:
        description: List of unique identifiers of custom network device validations.
        elements: str
        type: list
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Software Image Management (SWIM) BulkUpdateImagesOnNetworkDevices
    description: Complete reference of the BulkUpdateImagesOnNetworkDevices API.
    link: https://developer.cisco.com/docs/dna-center/#!bulk-update-images-on-network-devices
notes:
  - SDK Method used are
    software_image_management_swim.SoftwareImageManagementSwim.bulk_update_images_on_network_devices,
  - Paths used are
    post /dna/intent/api/v1/networkDeviceImages/activate/bulk,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.network_device_images_activate_bulk:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    payload:
      - compatibleFeatures:
          - key: string
            value: string
        id: string
        installedImages:
          - id: string
        networkValidationIds:
          - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: iot_rep_rings_query
short_description: Resource module for Iot Rep Rings Query
description:
  - Manage operation create of the resource Iot Rep Rings Query. - > This API returns the list of REP rings for the given
    fields - networkDeviceId Network device ID of the REP ring member. In case of successful REP ring creation, any of the
    REP ring member networkDeviceId can be provided. In case of failed REP ring creation, provide only root node networkDeviceId.
    The networkDeviceId is the instanceUuid attribute in the response of API - /dna/intent/api/v1/networkDevice and deploymentMode
    FABRIC/NON_FABRIC .
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  deploymentMode:
    description: Deployment mode of the configured REP ring.
    type: str
  limit:
    description: The number of records to show for this page.
    type: int
  networkDeviceId:
    description: Network device id of the REP ring member. API `/dna/intent/api/v1/networkDevices` can be used to get the
      list of networkDeviceIds of the neighbors , `instanceUuid` attribute in the response contains networkDeviceId.
    type: str
  offset:
    description: The first record to show for this page; the first record is numbered 1.
    type: int
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Industrial Configuration RetrievesTheListOfREPRings
    description: Complete reference of the RetrievesTheListOfREPRings API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-list-of-rep-rings
notes:
  - SDK Method used are
    industrial_configuration.IndustrialConfiguration.retrieves_the_list_of_r_e_p_rings,
  - Paths used are
    post /dna/intent/api/v1/iot/repRings/query,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.iot_rep_rings_query:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    deploymentMode: string
    limit: 0
    networkDeviceId: string
    offset: 0
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: list
  sample: >
    [
      {
        "response": [
          {
            "id": "string",
            "rootNetworkDeviceId": "string",
            "rootNeighbourNetworkDeviceIds": [
              "string"
            ],
            "status": "string",
            "repSegmentId": 0,
            "deploymentMode": "string",
            "ringName": "string",
            "ringMembers": [
              {
                "networkDeviceId": "string",
                "nodeName": "string",
                "portName1": "string",
                "portName2": "string",
                "ringOrder": 0
              }
            ]
          }
        ],
        "version": 0
      }
    ]
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: access_groups
short_description: Resource module for Access Groups
description:
  - Manage operations create, update and delete of the resource Access Groups.
  - Add an access group into the system.
  - Delete an access group from the system.
  - Update an access group in the system.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  description:
    description: Description of the access group.
    type: str
  id:
    description: Id path parameter. Id of the access group to be deleted.
    type: str
  name:
    description: Name of the access group.
    type: str
  resourceGroups:
    description: Access Groups's resourceGroups.
    elements: dict
    suboptions:
      name:
        description: The name of the resource. This should always be the site hierarchy id you would like to associate to
          this access group to.
        type: str
      srcResourceId:
        description: Id of the resource. This should be the site hierarchy id of the site you wish to scope this access group
          to. Please refer to the description for more details.
        type: str
      type:
        description: The type of resource. Currently, the only supported value is "site".
        type: str
    type: list
  role:
    description: List of role names.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for User and Roles AddAccessGroup
    description: Complete reference of the AddAccessGroup API.
    link: https://developer.cisco.com/docs/dna-center/#!add-access-group
  - name: Cisco DNA Center documentation for User and Roles DeleteAccessGroup
    description: Complete reference of the DeleteAccessGroup API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-access-group
  - name: Cisco DNA Center documentation for User and Roles UpdateAccessGroup
    description: Complete reference of the UpdateAccessGroup API.
    link: https://developer.cisco.com/docs/dna-center/#!update-access-group
notes:
  - SDK Method used are
    userand_roles.UserandRoles.add_access_group,
    userand_roles.UserandRoles.delete_access_group,
    userand_roles.UserandRoles.update_access_group,
  - Paths used are
    post /dna/system/api/v1/accessGroups,
    delete /dna/system/api/v1/accessGroups/{id},
    put /dna/system/api/v1/accessGroups/{id},
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.access_groups:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    description: string
    name: string
    resourceGroups:
      - name: string
        srcResourceId: string
        type: string
    role:
      - string
- name: Delete by id
  cisco.dnac.access_groups:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
- name: Update by id
  cisco.dnac.access_groups:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    description: string
    id: string
    resourceGroups:
      - name: string
        srcResourceId: string
        type: string
    role:
      - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "id": "string",
      "accessGroupInfo": {
        "name": "string",
        "description": "string",
        "resourceGroups": [
          {
            "name": "string",
            "srcResourceId": "string",
            "type": "string"
          }
        ],
        "role": [
          "string"
        ]
      },
      "meta": {
        "created": "string",
        "createdBy": "string",
        "lastModified": "string",
        "lastModifiedBy": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: compliance_policys_sites_rules_variables
short_description: Resource module for Compliance Policys Sites Rules Variables
description:
  - Manage operation update of the resource Compliance Policys Sites Rules Variables.
  - Set site variable values for the specified rule within the compliance policy.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  policyId:
    description: PolicyId path parameter. The `id` of the compliance policy.
    type: str
  ruleId:
    description: RuleId path parameter. The `id` of the rule within the compliance policy.
    type: str
  siteId:
    description: SiteId path parameter. The `id` of the site to which compliance policy is associated.
    type: str
  variableValues:
    description: Compliance Policys Sites Rules Variables's variableValues.
    elements: dict
    suboptions:
      id:
        description: The `id` of the variable.
        type: str
      values:
        description: List of variable values. The order of the list is preserved for compliance checks. The variable value
          is formatted as a string. It must be a valid string representation of the data and conform to the specified type.
          For variables with an input type of `SINGLE_SELECT` or `MULTI_SELECT`, pass the actual value, not the key.
        elements: str
        type: list
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Compliance SetSiteVariables
    description: Complete reference of the SetSiteVariables API.
    link: https://developer.cisco.com/docs/dna-center/#!set-site-variables
notes:
  - SDK Method used are
    compliance.Compliance.set_site_variables,
  - Paths used are
    put /dna/intent/api/v1/compliancePolicys/{policyId}/sites/{siteId}/rules/{ruleId}/variables,
"""

EXAMPLES = r"""
---
- name: Update all
  cisco.dnac.compliance_policys_sites_rules_variables:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    policyId: string
    ruleId: string
    siteId: string
    variableValues:
      - id: string
        values:
          - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: aaa_services_id_trend_analytics
short_description: Resource module for Aaa Services Id Trend Analytics
description:
  - Manage operation create of the resource Aaa Services Id Trend Analytics. - > Gets the trend analytics data related to
    a particular AAA Service matching the id. For detailed information about the usage of the API, please refer to the Open
    API specification document - https //github.com/cisco-en- programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
    AAAServices-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  aggregateAttributes:
    description: Aaa Services Id Trend Analytics's aggregateAttributes.
    elements: dict
    suboptions:
      function:
        description: Function.
        type: str
      name:
        description: Name.
        type: str
    type: list
  attributes:
    description: Attributes.
    elements: str
    type: list
  endTime:
    description: End Time.
    type: int
  filters:
    description: Aaa Services Id Trend Analytics's filters.
    elements: dict
    suboptions:
      filters:
        description: Filters.
        elements: str
        type: list
      key:
        description: Key.
        type: str
      logicalOperator:
        description: Logical Operator.
        type: str
      operator:
        description: Operator.
        type: str
      value:
        description: Aaa Services Id Trend Analytics's value.
        type: dict
    type: list
  groupBy:
    description: Group By.
    elements: str
    type: list
  headers:
    description: Additional headers.
    type: dict
  id:
    description: Id path parameter. Unique id of the AAA Service. It is the combination of AAA Server IP (`serverIp`) and
      Device UUID (`deviceId`) separated by underscore (`_`). Example If `serverIp` is `10.76.81.33` and `deviceId` is `6bef213c-19ca-4170-8375-b694e251101c`,
      then the `id` would be `10.76.81.33_6bef213c-19ca-4170-8375-b694e251101c`.
    type: str
  page:
    description: Aaa Services Id Trend Analytics's page.
    suboptions:
      limit:
        description: Limit.
        type: int
      offset:
        description: Offset.
        type: int
      timestampOrder:
        description: Timestamp Order.
        type: str
    type: dict
  startTime:
    description: Start Time.
    type: int
  trendInterval:
    description: Trend Interval.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices GetTrendAnalyticsDataForAGivenAAAServiceMatchingTheIdOfTheService
    description: Complete reference of the GetTrendAnalyticsDataForAGivenAAAServiceMatchingTheIdOfTheService API.
    link: https://developer.cisco.com/docs/dna-center/#!get-trend-analytics-data-for-a-given-aaa-service-matching-the-id-of-the-service
notes:
  - SDK Method used are
    devices.Devices.get_trend_analytics_data_for_a_given_aaa_service_matching_the_id_of_the_service,
  - Paths used are
    post /dna/data/api/v1/aaaServices/{id}/trendAnalytics,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.aaa_services_id_trend_analytics:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    aggregateAttributes:
      - function: string
        name: string
    attributes:
      - string
    endTime: 0
    filters:
      - filters:
          - string
        key: string
        logicalOperator: string
        operator: string
        value: {}
    groupBy:
      - string
    headers: '{{my_headers | from_json}}'
    id: string
    page:
      limit: 0
      offset: 0
      timestampOrder: string
    startTime: 0
    trendInterval: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": [
        {
          "timestamp": 0,
          "groups": [
            {
              "id": "string",
              "attributes": [
                {
                  "name": "string",
                  "value": "string"
                }
              ],
              "aggregateAttributes": [
                {
                  "name": "string",
                  "function": "string",
                  "value": 0
                }
              ]
            }
          ],
          "attributes": [
            {
              "name": "string",
              "value": "string"
            }
          ],
          "aggregateAttributes": [
            {
              "name": "string",
              "function": "string",
              "value": 0
            }
          ]
        }
      ],
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "timestampOrder": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: application_visibility_network_devices_enable_app_telemetry
short_description: Resource module for Application Visibility Network Devices Enable App Telemetry
description:
  - Manage operation create of the resource Application Visibility Network Devices Enable App Telemetry.
  - This API can be used to enable application telemetry feature on multiple network devices.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  networkDevices:
    description: Application Visibility Network Devices Enable App Telemetry's networkDevices.
    elements: dict
    suboptions:
      id:
        description: Network device identifier.
        type: str
      includeGuestSsids:
        description: Flag to indicate whether guest SSIDs should be included for application telemetry enablement. Applicable
          only for wireless devices. Default value is false.
        type: bool
      includeWlanModes:
        description: Types of WLAN modes which needs to be included for enablement. Applicable and mandatory only for wireless
          devices. Available values LOCAL or NON_LOCAL.
        elements: str
        type: list
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Application Policy EnableApplicationTelemetryFeatureOnMultipleNetworkDevices
    description: Complete reference of the EnableApplicationTelemetryFeatureOnMultipleNetworkDevices API.
    link: https://developer.cisco.com/docs/dna-center/#!enable-application-telemetry-feature-on-multiple-network-devices
notes:
  - SDK Method used are
    application_policy.ApplicationPolicy.enable_application_telemetry_feature_on_multiple_network_devices,
  - Paths used are
    post /dna/intent/api/v1/applicationVisibility/networkDevices/enableAppTelemetry,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.application_visibility_network_devices_enable_app_telemetry:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    networkDevices:
      - id: string
        includeGuestSsids: true
        includeWlanModes:
          - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: compliance_policys
short_description: Resource module for Compliance Policys
description:
  - Manage operations create, update and delete of the resource Compliance Policys.
  - This API operation creates a new compliance policy.
  - Deletes a specific compliance policy.
  - Updates the details of an existing compliance policy.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  description:
    description: An optional field for providing a detailed description of the compliance policy.
    type: str
  id:
    description: Id path parameter. The `id` of the compliance policy.
    type: str
  name:
    description: The unique name of the compliance policy.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Compliance CreateANewPolicy
    description: Complete reference of the CreateANewPolicy API.
    link: https://developer.cisco.com/docs/dna-center/#!create-a-new-policy
  - name: Cisco DNA Center documentation for Compliance DeleteASpecificPolicy
    description: Complete reference of the DeleteASpecificPolicy API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-a-specific-policy
  - name: Cisco DNA Center documentation for Compliance UpdateAnExistingPolicy
    description: Complete reference of the UpdateAnExistingPolicy API.
    link: https://developer.cisco.com/docs/dna-center/#!update-an-existing-policy
notes:
  - SDK Method used are
    compliance.Compliance.create_a_new_policy,
    compliance.Compliance.delete_a_specific_policy,
    compliance.Compliance.update_an_existing_policy,
  - Paths used are
    post /dna/intent/api/v1/compliancePolicys,
    delete /dna/intent/api/v1/compliancePolicys/{id},
    put /dna/intent/api/v1/compliancePolicys/{id},
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.compliance_policys:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    description: string
    name: string
- name: Delete by id
  cisco.dnac.compliance_policys:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
- name: Update by id
  cisco.dnac.compliance_policys:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    description: string
    id: string
    name: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_device_images_validations
short_description: Resource module for Network Device Images Validations
description:
  - Manage operations create, update and delete of the resource Network Device Images Validations. - > Custom network device
    validation refers to the tailored process of verifying and assessing the configurations of network devices based on specific
    organizational requirements and unique network environments. Unlike standard validations, custom network device validations
    are designed to address the distinctive needs and challenges of a particular network infrastructure, ensuring that devices
    operate optimally within the defined parameters. Upon task completion, the task API response's `resultLocation` attribute
    will provide the URL to retrieve the validation id.
  - Delete the custom network device validation.
  - Update the custom network device validation details.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  cli:
    description:
      - Show commands that will be executed.
      - Validate the CLI - Cisco DevNet https //developer.cisco.com/docs/dna-center/2-3-7/run-read-only-commands...
    type: str
  description:
    description: Details of the network device validation.
    type: str
  id:
    description: Id path parameter. Unique identifier of network device validation.
    type: str
  name:
    description: Name of the network device validation.
    type: str
  operationType:
    description: The operation type, as part of which this validation will get triggered.
    type: str
  productSeriesOrdinals:
    description: The custom check will be mapped to the product series and devices that belong to this series. These devices
      will consume this check when triggered. Fetch productSeriesOrdinal from API `/dna/intent/api/v1/productSeries`.
    elements: float
    type: list
  type:
    description: The type of network device validation determines whether this validation runs before or after the operation.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Software Image Management (SWIM) CreateCustomNetworkDeviceValidation
    description: Complete reference of the CreateCustomNetworkDeviceValidation API.
    link: https://developer.cisco.com/docs/dna-center/#!create-custom-network-device-validation
  - name: Cisco DNA Center documentation for Software Image Management (SWIM) DeleteCustomNetworkDeviceValidation
    description: Complete reference of the DeleteCustomNetworkDeviceValidation API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-custom-network-device-validation
  - name: Cisco DNA Center documentation for Software Image Management (SWIM) UpdateCustomNetworkDeviceValidation
    description: Complete reference of the UpdateCustomNetworkDeviceValidation API.
    link: https://developer.cisco.com/docs/dna-center/#!update-custom-network-device-validation
notes:
  - SDK Method used are
    software_image_management_swim.SoftwareImageManagementSwim.create_custom_network_device_validation,
    software_image_management_swim.SoftwareImageManagementSwim.delete_custom_network_device_validation,
    software_image_management_swim.SoftwareImageManagementSwim.update_custom_network_device_validation,
  - Paths used are
    post /dna/intent/api/v1/networkDeviceImages/validations,
    delete /dna/intent/api/v1/networkDeviceImages/validations/{id},
    put /dna/intent/api/v1/networkDeviceImages/validations/{id},
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.network_device_images_validations:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    cli: string
    description: string
    name: string
    operationType: string
    productSeriesOrdinals:
      - 0
    type: string
- name: Delete by id
  cisco.dnac.network_device_images_validations:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
- name: Update by id
  cisco.dnac.network_device_images_validations:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    cli: string
    description: string
    id: string
    productSeriesOrdinals:
      - 0
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: transit_network_health_summaries_id_trend_analytics_info
short_description: Information module for Transit Network Health Summaries Id Trend Analytics
description:
  - Get all Transit Network Health Summaries Id Trend Analytics.
  - Get health time series for a specific Transit Network by providing the unique Transit Network id in the url path.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. The unique transit network id, Ex "1551156a-bc97-3c63-aeda-8a6d3765b5b9".
    type: str
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which API queries the data set related to the resource. It
        must be specified in UNIX epochtime in milliseconds. Value is inclusive.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API queries the data set related to the resource. It must be
        specified in UNIX epochtime in milliseconds. Value is inclusive.
    type: float
  trendInterval:
    description:
      - >
        TrendInterval query parameter. The time window to aggregate the metrics. Interval can be 5 minutes or 10
        minutes or 1 hour or 1 day or 7 days.
    type: str
  limit:
    description:
      - Limit query parameter. Maximum number of records to return.
    type: int
  offset:
    description:
      - >
        Offset query parameter. Specifies the starting point within all records returned by the API. It's one
        based offset. The starting value is 1.
    type: int
  order:
    description:
      - Order query parameter. The sort order of the field ascending or descending.
    type: str
  attribute:
    description:
      - Attribute query parameter. The interested fields in the request. For valid attributes, verify the documentation.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for SDA TheTrendAnalyticsDataForATransitNetworkInTheSpecifiedTimeRange
    description: Complete reference of the TheTrendAnalyticsDataForATransitNetworkInTheSpecifiedTimeRange API.
    link: https://developer.cisco.com/docs/dna-center/#!the-trend-analytics-data-for-a-transit-network-in-the-specified-time-range
notes:
  - SDK Method used are
    sda.Sda.the_trend_analytics_data_for_a_transit_network_in_the_specified_time_range,
  - Paths used are
    get /dna/data/api/v1/transitNetworkHealthSummaries/{id}/trendAnalytics,
"""

EXAMPLES = r"""
---
- name: Get all Transit Network Health Summaries Id Trend Analytics
  cisco.dnac.transit_network_health_summaries_id_trend_analytics_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    trendInterval: string
    limit: 0
    offset: 0
    order: string
    attribute: string
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "timestamp": 0,
          "attributes": [
            {
              "name": "string",
              "value": 0
            }
          ]
        }
      ],
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "timeSortOrder": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: credential_to_site_by_siteid_create_v2
short_description: Resource module for Credential To Site By Siteid Create V2
description:
  - Manage operation create of the resource Credential To Site By Siteid Create V2.
  - API to assign Device Credential to a site.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  cliId:
    description: CLI Credential Id.
    type: str
  httpRead:
    description: HTTP(S) Read Credential Id.
    type: str
  httpWrite:
    description: HTTP(S) Write Credential Id.
    type: str
  siteId:
    description: SiteId path parameter. Site Id to assign credential.
    type: str
  snmpV2ReadId:
    description: SNMPv2c Read Credential Id.
    type: str
  snmpV2WriteId:
    description: SNMPv2c Write Credential Id.
    type: str
  snmpV3Id:
    description: SNMPv3 Credential Id.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Network Settings AssignDeviceCredentialToSiteV2
    description: Complete reference of the AssignDeviceCredentialToSiteV2 API.
    link: https://developer.cisco.com/docs/dna-center/#!assign-device-credential-to-site-v-2
notes:
  - SDK Method used are
    network_settings.NetworkSettings.assign_device_credential_to_site_v2,
  - Paths used are
    post /dna/intent/api/v2/credential-to-site/{siteId},
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.credential_to_site_by_siteid_create_v2:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    cliId: string
    httpRead: string
    httpWrite: string
    siteId: string
    snmpV2ReadId: string
    snmpV2WriteId: string
    snmpV3Id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: energy_network_devices_count_info
short_description: Information module for Energy Network Devices Count
description:
  - Get all Energy Network Devices Count.
  - Retrieves the total count of network devices that provide energy data, filtered according to query parameters.
  - For detailed information about the usage of the API, please refer to the Open API specification document
    https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/
    CE_Cat_Center_Org-deviceEnergy_1.0-1.0.1-resolved.yaml.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which API queries the data set related to the resource. It
        must be specified in UNIX epochtime in milliseconds. Value is inclusive. If `startTime` is not provided,
        API will default to one day before `endTime`.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API queries the data set related to the resource. It must be
        specified in UNIX epochtime in milliseconds. Value is inclusive. If `endTime` is not provided, API will
        default to one day after `startTime`. If `startTime` is not provided either, API will default to current
        time.
    type: float
  id:
    description:
      - >
        Id query parameter. The list of Device Uuids (e.g., `6bef213c-19ca-4170-8375-b694e251101c`). Examples
        `id=6bef213c-19ca-4170-8375-b694e251101c` (single device requested)
        `id=6bef213c-19ca-4170-8375-b694e251101c&id=32219612-819e-4b5e-a96b-cf22aca13dd9`.
    type: str
  siteId:
    description:
      - >
        SiteId query parameter. The UUID of the site. (Ex. `flooruuid`) Examples `?siteId=id1` (single id
        requested) `?siteId=id1&siteId=id2&siteId=id3` (multiple ids requested).
    type: str
  siteHierarchy:
    description:
      - >
        SiteHierarchy query parameter. The full hierarchical breakdown of the site tree starting from Global
        site name and ending with the specific site name. The Root site is named "Global" (Ex.
        `Global/AreaName/BuildingName/FloorName`) This field supports wildcard asterisk (`*`) character search
        support. E.g. `*/San*, */San, /San*` Examples `?siteHierarchy=Global/AreaName/BuildingName/FloorName`
        (single siteHierarchy requested) `?siteHierarchy=Global/AreaName/BuildingName/FloorName&siteHierarchy=Gl
        obal/AreaName2/BuildingName2/FloorName2` (multiple siteHierarchies requested).
    type: str
  siteHierarchyId:
    description:
      - >
        SiteHierarchyId query parameter. The full hierarchy breakdown of the site tree in id form starting from
        Global site UUID and ending with the specific site UUID. (Ex.
        `globalUuid/areaUuid/buildingUuid/floorUuid`) This field supports wildcard asterisk (`*`) character
        search support. E.g. `*uuid*, *uuid, uuid*` Examples
        `?siteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid `(single siteHierarchyId requested) `?siteH
        ierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid&siteHierarchyId=globalUuid/areaUuid2/buildingUuid2
        /floorUuid2` (multiple siteHierarchyIds requested).
    type: str
  deviceCategory:
    description:
      - >
        DeviceCategory query parameter. The list of device deviceCategories. Examples `deviceCategory=Switch`
        (single device family requested) `deviceCategory=Switch&deviceCategory=Router` (multiple device
        categories with comma separator).
    type: str
  deviceSubCategory:
    description:
      - >
        DeviceSubCategory query parameter. The list of device sub categories. Examples `deviceSubCategory=Cisco
        Catalyst 9300 Series Switches` (single device family requested) `deviceSubCategory=Cisco Catalyst 9300
        Series Switches&deviceSubCategory=Cisco Catalyst 9400 Series Switches`.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices CountDevicesEnergy
    description: Complete reference of the CountDevicesEnergy API.
    link: https://developer.cisco.com/docs/dna-center/#!count-devices-energy
notes:
  - SDK Method used are
    devices.Devices.count_devices_energy,
  - Paths used are
    get /dna/data/api/v1/energy/networkDevices/count,
"""

EXAMPLES = r"""
---
- name: Get all Energy Network Devices Count
  cisco.dnac.energy_network_devices_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    id: string
    siteId: string
    siteHierarchy: string
    siteHierarchyId: string
    deviceCategory: string
    deviceSubCategory: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: field_notices_results_network_devices_network_device_id_notices_info
short_description: Information module for Field Notices Results Network Devices Network Device Id Notices
description:
  - Get all Field Notices Results Network Devices Network Device Id Notices.
  - Get Field Notices Results Network Devices Network Device Id Notices by id.
  - Get field notice affecting the network device by device Id and notice id.
  - Get field notices affecting the network device.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  networkDeviceId:
    description:
      - NetworkDeviceId path parameter. Id of the network device.
    type: str
  id:
    description:
      - Id query parameter. Id of the field notice.
    type: str
  type:
    description:
      - Type query parameter. Return field notices with this type. Available values SOFTWARE, HARDWARE.
    type: str
  offset:
    description:
      - >
        Offset query parameter. The first record to show for this page; the first record is numbered 1. Default
        value is 1.
    type: int
  limit:
    description:
      - >
        Limit query parameter. The number of records to show for this page. Minimum value is 1. Maximum value is
        500. Default value is 500.
    type: int
  sortBy:
    description:
      - SortBy query parameter. A property within the response to sort by.
    type: str
  order:
    description:
      - >
        Order query parameter. Whether ascending or descending order should be used to sort the response.
        Available values asc, desc. Default value is asc.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Compliance GetFieldNoticeAffectingTheNetworkDeviceByDeviceIdAndNoticeId
    description: Complete reference of the GetFieldNoticeAffectingTheNetworkDeviceByDeviceIdAndNoticeId API.
    link: https://developer.cisco.com/docs/dna-center/#!get-field-notice-affecting-the-network-device-by-device-id-and-notice-id
  - name: Cisco DNA Center documentation for Compliance GetFieldNoticesAffectingTheNetworkDevice
    description: Complete reference of the GetFieldNoticesAffectingTheNetworkDevice API.
    link: https://developer.cisco.com/docs/dna-center/#!get-field-notices-affecting-the-network-device
notes:
  - SDK Method used are
    compliance.Compliance.get_field_notice_affecting_the_network_device_by_device_id_and_notice_id,
    compliance.Compliance.get_field_notices_affecting_the_network_device,
  - Paths used are
    get /dna/intent/api/v1/fieldNotices/results/networkDevices/{networkDeviceId}/notices,
    get /dna/intent/api/v1/fieldNotices/results/networkDevices/{networkDeviceId}/notices/{id},
"""

EXAMPLES = r"""
---
- name: Get all Field Notices Results Network Devices Network Device Id Notices
  cisco.dnac.field_notices_results_network_devices_network_device_id_notices_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
    type: string
    offset: 0
    limit: 0
    sortBy: string
    order: string
    networkDeviceId: string
  register: result
- name: Get Field Notices Results Network Devices Network Device Id Notices by id
  cisco.dnac.field_notices_results_network_devices_network_device_id_notices_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    networkDeviceId: string
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "name": "string",
        "publicationUrl": "string",
        "deviceCount": 0,
        "potentialDeviceCount": 0,
        "type": "string",
        "firstPublishDate": 0,
        "lastUpdatedDate": 0,
        "matchConfidence": "string",
        "matchReason": "string",
        "networkDeviceId": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: application_visibility_network_devices_enable_cbar
short_description: Resource module for Application Visibility Network Devices Enable Cbar
description:
  - Manage operation create of the resource Application Visibility Network Devices Enable Cbar.
  - This API can be used to enable CBAR feature on multiple network devices. Request payload.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  networkDevices:
    description: Application Visibility Network Devices Enable Cbar's networkDevices.
    elements: dict
    suboptions:
      excludeInterfaceIds:
        description: List of interface identifiers which needs to be excluded from CBAR enablement. Applicable only for wired
          devices. Please note that this list considered as absolute exclusion and earlier exclusions are not considered.
          For example, if IF1 and IF2 have already been excluded from CBAR as part of earlier enablement, and this API is
          now called with IF3 and IF4 as inputs, then IF1 and IF2 are removed from exclusion list and only IF3 and IF4 are
          excluded.
        elements: str
        type: list
      excludeWlanModes:
        description: WLAN modes which needs to be excluded from CBAR enablement. Applicable only for wireless devices. Applicable
          values are LOCAL, FLEX, or FABRIC.
        elements: str
        type: list
      id:
        description: Network device identifier.
        type: str
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Application Policy EnableCBARFeatureOnMultipleNetworkDevices
    description: Complete reference of the EnableCBARFeatureOnMultipleNetworkDevices API.
    link: https://developer.cisco.com/docs/dna-center/#!enable-cbar-feature-on-multiple-network-devices
notes:
  - SDK Method used are
    application_policy.ApplicationPolicy.enable_c_b_a_r_feature_on_multiple_network_devices,
  - Paths used are
    post /dna/intent/api/v1/applicationVisibility/networkDevices/enableCbar,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.application_visibility_network_devices_enable_cbar:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    networkDevices:
      - excludeInterfaceIds:
          - string
        excludeWlanModes:
          - string
        id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: discoverys_info
short_description: Information module for Discoverys
description:
  - Get all Discoverys.
  - Get Discoverys by id.
  - API to fetch the discovery details using basic filters.
  - API to get discovery details for the given discovery id.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id query parameter. Optional list of the discovery ids to filter by.
    type: str
  limit:
    description:
      - Limit query parameter. The number of records to show for this page.
    type: int
  name:
    description:
      - >
        Name query parameter. Optional name of the discovery to filter by. This supports partial search. For
        example, searching for "Disc" will match "Discovery1", "Discovery2", etc.
    type: str
  offset:
    description:
      - Offset query parameter. The first record to show for this page; the first record is numbered 1.
    type: int
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices FetchesAllDiscoveryDetails
    description: Complete reference of the FetchesAllDiscoveryDetails API.
    link: https://developer.cisco.com/docs/dna-center/#!fetches-all-discovery-details
  - name: Cisco DNA Center documentation for Devices FetchesDiscoveryDetailsById
    description: Complete reference of the FetchesDiscoveryDetailsById API.
    link: https://developer.cisco.com/docs/dna-center/#!fetches-discovery-details-by-id
notes:
  - SDK Method used are
    devices.Devices.fetches_all_discovery_details,
    devices.Devices.fetches_discovery_details_by_id,
  - Paths used are
    get /dna/intent/api/v1/discoverys,
    get /dna/intent/api/v1/discoverys/{id},
"""

EXAMPLES = r"""
---
- name: Get all Discoverys
  cisco.dnac.discoverys_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
    limit: 0
    name: string
    offset: 0
  register: result
- name: Get Discoverys by id
  cisco.dnac.discoverys_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "name": "string",
        "managementIpSelectionMethod": "string",
        "discoveryTypeDetails": {
          "type": "string",
          "ipAddress": "string",
          "range": [
            {
              "ipAddressStart": "string",
              "ipAddressEnd": "string"
            }
          ],
          "cidrAddress": {
            "cidrPrefix": "string",
            "cidrSuffix": 0
          },
          "subnetFilter": {
            "ipAddress": "string",
            "cidrAddress": {
              "cidrPrefix": "string",
              "cidrSuffix": 0
            }
          },
          "hopCount": 0
        },
        "onlyNewDevice": true,
        "updateManagementIp": true,
        "credentials": {
          "cli": {
            "description": "string",
            "username": "string",
            "globalCredentialIdList": [
              "string"
            ],
            "protocolOrder": "string"
          },
          "snmp": {
            "snmpV2Read": {
              "description": "string",
              "globalCredentialIdList": [
                "string"
              ]
            },
            "snmpV2Write": {
              "description": "string",
              "globalCredentialIdList": [
                "string"
              ]
            },
            "snmpV3": {
              "description": "string",
              "mode": "string",
              "username": "string",
              "authType": "string",
              "privacyType": "string",
              "globalCredentialIdList": [
                "string"
              ]
            },
            "retries": 0,
            "timeout": 0
          },
          "httpRead": {
            "description": "string",
            "username": "string",
            "port": 0,
            "protocol": "string",
            "globalCredentialIdList": [
              "string"
            ]
          },
          "httpWrite": {
            "description": "string",
            "username": "string",
            "port": 0,
            "protocol": "string",
            "globalCredentialIdList": [
              "string"
            ]
          },
          "netconf": {
            "port": 0,
            "description": "string",
            "globalCredentialIdList": [
              "string"
            ]
          }
        }
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: clients_info
short_description: Information module for Clients
description:
  - Get all Clients.
  - Get Clients by id.
  - Retrieves specific client information matching the MAC address.
  - For detailed information about the usage of the API, please refer to the Open API specification document
    https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-clients1-1.0.0-resolved.yaml.
  - Retrieves the list of clients, while also offering basic filtering and sorting capabilities.
  - For detailed information about the usage of the API, please refer to the Open API specification document
    https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-clients1-1.0.0-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which API queries the data set related to the resource. It
        must be specified in UNIX epochtime in milliseconds. Value is inclusive. If `startTime` is not provided,
        API will default to current time.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API queries the data set related to the resource. It must be
        specified in UNIX epochtime in milliseconds. Value is inclusive.
    type: float
  limit:
    description:
      - Limit query parameter. Maximum number of records to return.
    type: int
  offset:
    description:
      - >
        Offset query parameter. Specifies the starting point within all records returned by the API. It's one
        based offset. The starting value is 1.
    type: int
  sortBy:
    description:
      - SortBy query parameter. A field within the response to sort by.
    type: str
  order:
    description:
      - Order query parameter. The sort order of the field ascending or descending.
    type: str
  type:
    description:
      - >
        Type query parameter. The client device type whether client is connected to network through Wired or
        Wireless medium.
    type: str
  osType:
    description:
      - >
        OsType query parameter. Client device operating system type. This field supports wildcard (`*`)
        character-based search. If the value contains the (`*`) character, please use the /query API for regex
        search. Ex `*iOS*` or `iOS*` or `*iOS` Examples `osType=iOS` (single osType requested)
        `osType=iOS&osType=Android` (multiple osType requested).
    type: str
  osVersion:
    description:
      - >
        OsVersion query parameter. Client device operating system version This field supports wildcard (`*`)
        character-based search. If the value contains the (`*`) character, please use the /query API for regex
        search. Ex `*14.3*` or `14.3*` or `*14.3` Examples `osVersion=14.3` (single osVersion requested)
        `osVersion=14.3&osVersion=10.1` (multiple osVersion requested).
    type: str
  siteHierarchy:
    description:
      - >
        SiteHierarchy query parameter. The full hierarchical breakdown of the site tree starting from Global
        site name and ending with the specific site name. The Root site is named "Global" (Ex.
        "Global/AreaName/BuildingName/FloorName") This field supports wildcard (`*`) character-based search. If
        the value contains the (`*`) character, please use the /query API for regex search. Ex `*BuildingName*`
        or `BuildingName*` or `*BuildingName` Examples `siteHierarchy=Global/AreaName/BuildingName/FloorName`
        (single siteHierarchy requested) `siteHierarchy=Global/AreaName/BuildingName1/FloorName1&siteHierarchy=G
        lobal/AreaName/BuildingName1/FloorName2` (multiple siteHierarchy requested).
    type: str
  siteHierarchyId:
    description:
      - >
        SiteHierarchyId query parameter. The full hierarchy breakdown of the site tree in id form starting from
        Global site UUID and ending with the specific site UUID. (Ex.
        "globalUuid/areaUuid/buildingUuid/floorUuid") This field supports wildcard (`*`) character-based search.
        Ex `*buildingUuid*` or `buildingUuid*` or `*buildingUuid` Examples
        `siteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid` (single siteHierarchyId requested) `siteHie
        rarchyId=globalUuid/areaUuid/buildingUuid1/floorUuid1&siteHierarchyId=globalUuid/areaUuid/buildingUuid1/
        floorUuid2` (multiple siteHierarchyId requested).
    type: str
  siteId:
    description:
      - >
        SiteId query parameter. The site UUID without the top level hierarchy. (Ex."floorUuid") Examples
        `siteId=floorUuid` (single siteId requested) `siteId=floorUuid1&siteId=floorUuid2` (multiple siteId
        requested).
    type: str
  ipv4Address:
    description:
      - >
        Ipv4Address query parameter. IPv4 Address of the network entity either network device or client This
        field supports wildcard (`*`) character-based search. Ex `*1.1*` or `1.1*` or `*1.1` Examples
        `ipv4Address=1.1.1.1` (single ipv4Address requested) `ipv4Address=1.1.1.1&ipv4Address=2.2.2.2` (multiple
        ipv4Address requested).
    type: str
  ipv6Address:
    description:
      - >
        Ipv6Address query parameter. IPv6 Address of the network entity either network device or client This
        field supports wildcard (`*`) character-based search. Ex `*2001 db8*` or `2001 db8*` or `*2001 db8`
        Examples `ipv6Address=2001 db8 0 0 0 0 2 1` (single ipv6Address requested) `ipv6Address=2001 db8 0 0 0 0
        2 1&ipv6Address=2001 db8 85a3 8d3 1319 8a2e 370 7348` (multiple ipv6Address requested).
    type: str
  macAddress:
    description:
      - >
        MacAddress query parameter. The macAddress of the network device or client This field supports wildcard
        (`*`) character-based search. Ex `*AB AB AB*` or `AB AB AB*` or `*AB AB AB` Examples `macAddress=AB AB
        AB CD CD CD` (single macAddress requested) `macAddress=AB AB AB CD CD DC&macAddress=AB AB AB CD CD FE`
        (multiple macAddress requested).
    type: str
  wlcName:
    description:
      - >
        WlcName query parameter. Wireless Controller name that reports the wireless client. This field supports
        wildcard (`*`) character-based search. If the value contains the (`*`) character, please use the /query
        API for regex search. Ex `*wlc-25*` or `wlc-25*` or `*wlc-25` Examples `wlcName=wlc-25` (single wlcName
        requested) `wlcName=wlc-25&wlc-34` (multiple wlcName requested).
    type: str
  connectedNetworkDeviceName:
    description:
      - >
        ConnectedNetworkDeviceName query parameter. Name of the neighbor network device that client is connected
        to. This field supports wildcard (`*`) character-based search. If the value contains the (`*`)
        character, please use the /query API for regex search. Ex `*ap-25*` or `ap-25*` or `*ap-25` Examples
        `connectedNetworkDeviceName=ap-25` (single connectedNetworkDeviceName requested)
        `connectedNetworkDeviceName=ap-25&ap-34` (multiple connectedNetworkDeviceName requested).
    type: str
  ssid:
    description:
      - >
        Ssid query parameter. SSID is the name of wireless network to which client connects to. It is also
        referred to as WLAN ID - Wireless Local Area Network Identifier. This field supports wildcard (`*`)
        character-based search. If the value contains the (`*`) character, please use the /query API for regex
        search. Ex `*Alpha*` or `Alpha*` or `*Alpha` Examples `ssid=Alpha` (single ssid requested)
        `ssid=Alpha&ssid=Guest` (multiple ssid requested).
    type: str
  band:
    description:
      - >
        Band query parameter. WiFi frequency band that client or Access Point operates. Band value is
        represented in Giga Hertz - GHz Examples `band=5GHZ` (single band requested) `band=2.4GHZ&band=6GHZ`
        (multiple band requested).
    type: str
  view:
    description:
      - >
        View query parameter. Client related Views Refer to ClientView schema for list of views supported
        Examples `view=Wireless` (single view requested) `view=WirelessHealth&view=WirelessTraffic` (multiple
        view requested).
    type: str
  attribute:
    description:
      - >
        Attribute query parameter. List of attributes related to resource that can be requested to only be part
        of the response along with the required attributes. Refer to ClientAttribute schema for list of
        attributes supported Examples `attribute=band` (single attribute requested)
        `attribute=band&attribute=ssid&attribute=overallScore` (multiple attribute requested).
    type: str
  id:
    description:
      - >
        Id path parameter. Id is the client mac address. It can be specified is any notational conventions 01 23
        45 67 89 AB or 01-23-45-67-89-AB or 0123.4567.89AB and is case insensitive.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Clients RetrievesSpecificClientInformationMatchingTheMACAddress
    description: Complete reference of the RetrievesSpecificClientInformationMatchingTheMACAddress API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-specific-client-information-matching-the-mac-address
  - name: Cisco DNA Center documentation for Clients RetrievesTheListOfClients_WhileAlsoOfferingBasicFilteringAndSortingCapabilities
    description: Complete reference of the RetrievesTheListOfClients_WhileAlsoOfferingBasicFilteringAndSortingCapabilities
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-list-of-clients-while-also-offering-basic-filtering-and-sorting-capabilities
notes:
  - SDK Method used are
    clients.Clients.retrieves_specific_client_information_matching_the_macaddress,
    clients.Clients.retrieves_the_list_of_clients_while_also_offering_basic_filtering_and_sorting_capabilities,
  - Paths used are
    get /dna/data/api/v1/clients,
    get /dna/data/api/v1/clients/{id},
"""

EXAMPLES = r"""
---
- name: Get all Clients
  cisco.dnac.clients_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    limit: 0
    offset: 0
    sortBy: string
    order: string
    type: string
    osType: string
    osVersion: string
    siteHierarchy: string
    siteHierarchyId: string
    siteId: string
    ipv4Address: string
    ipv6Address: string
    macAddress: string
    wlcName: string
    connectedNetworkDeviceName: string
    ssid: string
    band: string
    view: string
    attribute: string
  register: result
- name: Get Clients by id
  cisco.dnac.clients_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    view: string
    attribute: string
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "macAddress": "string",
        "type": "string",
        "name": "string",
        "userId": "string",
        "username": "string",
        "ipv4Address": "string",
        "ipv6Addresses": [
          "string"
        ],
        "vendor": "string",
        "osType": "string",
        "osVersion": "string",
        "formFactor": "string",
        "siteHierarchy": "string",
        "siteHierarchyId": "string",
        "siteId": "string",
        "lastUpdatedTime": 0,
        "connectionStatus": "string",
        "tracked": "string",
        "isPrivateMacAddress": true,
        "health": {
          "overallScore": 0,
          "onboardingScore": 0,
          "connectedScore": 0,
          "linkErrorPercentageThreshold": 0,
          "isLinkErrorIncluded": true,
          "rssiThreshold": 0,
          "snrThreshold": 0,
          "isRssiIncluded": true,
          "isSnrIncluded": true
        },
        "traffic": {
          "txBytes": 0,
          "rxBytes": 0,
          "usage": 0,
          "rxPackets": 0,
          "txPackets": 0,
          "rxRate": 0,
          "txRate": 0,
          "rxLinkErrorPercentage": 0,
          "txLinkErrorPercentage": 0,
          "rxRetries": 0,
          "rxRetryPercentage": 0,
          "txDrops": 0,
          "txDropPercentage": 0,
          "dnsRequestCount": 0,
          "dnsResponseCount": 0
        },
        "connectedNetworkDevice": {
          "connectedNetworkDeviceId": "string",
          "connectedNetworkDeviceName": "string",
          "connectedNetworkDeviceManagementIp": "string",
          "connectedNetworkDeviceMac": "string",
          "connectedNetworkDeviceType": "string",
          "interfaceName": "string",
          "interfaceSpeed": 0,
          "duplexMode": "string"
        },
        "connection": {
          "vlanId": "string",
          "sessionDuration": 0,
          "vnId": "string",
          "l2Vn": "string",
          "l3Vn": "string",
          "securityGroupTag": "string",
          "linkSpeed": 0,
          "bridgeVMMode": "string",
          "band": "string",
          "ssid": "string",
          "authType": "string",
          "wlcName": "string",
          "wlcId": "string",
          "apMac": "string",
          "apEthernetMac": "string",
          "apMode": "string",
          "radioId": 0,
          "channel": "string",
          "channelWidth": "string",
          "protocol": "string",
          "protocolCapability": "string",
          "upnId": "string",
          "upnName": "string",
          "upnOwner": "string",
          "upnDuid": "string",
          "rssi": 0,
          "snr": 0,
          "dataRate": 0,
          "isIosAnalyticsCapable": true
        },
        "onboarding": {
          "avgRunDuration": 0,
          "maxRunDuration": 0,
          "avgAssocDuration": 0,
          "maxAssocDuration": 0,
          "avgAuthDuration": 0,
          "maxAuthDuration": 0,
          "avgDhcpDuration": 0,
          "maxDhcpDuration": 0,
          "maxRoamingDuration": 0,
          "aaaServerIp": "string",
          "dhcpServerIp": "string",
          "onboardingTime": 0,
          "authDoneTime": 0,
          "assocDoneTime": 0,
          "dhcpDoneTime": 0,
          "roamingTime": 0,
          "failedRoamingCount": 0,
          "successfulRoamingCount": 0,
          "totalRoamingAttempts": 0,
          "assocFailureReason": "string",
          "aaaFailureReason": "string",
          "dhcpFailureReason": "string",
          "otherFailureReason": "string",
          "latestFailureReason": "string"
        },
        "latency": {
          "video": 0,
          "voice": 0,
          "bestEffort": 0,
          "background": 0
        }
      },
      "version": "string"
    }
"""
